==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Template.pm <==
package WebGUI::i18n::German::Asset_Template;
use utf8;
our $I18N = {
  'Already attached!' => {
    'lastUpdated' => '1258547405',
    'message' => 'Bereits angehängt!'
  },
  'No url!' => {
    'lastUpdated' => '1258547392',
    'message' => 'Keine URL!'
  },
  'assetName' => {
    'lastUpdated' => '1179920785',
    'message' => 'Template'
  },
  'attachment add button' => {
    'lastUpdated' => '1243496763',
    'message' => 'Hinzufügen'
  },
  'attachment add field label' => {
    'lastUpdated' => '1243496838',
    'message' => 'Anhang hinzufügen'
  },
  'attachment display label' => {
    'lastUpdated' => '1243496774',
    'message' => 'Anhänge'
  },
  'attachment header index' => {
    'lastUpdated' => '1243496871',
    'message' => 'Anhang-Nr.'
  },
  'attachment header remove' => {
    'lastUpdated' => '1243496881',
    'message' => 'Entfernen'
  },
  'attachment header type' => {
    'lastUpdated' => '1243496897',
    'message' => 'Typ'
  },
  'attachment header url' => {
    'lastUpdated' => '1243496908',
    'message' => 'Url'
  },
  'body background color' => {
    'lastUpdated' => '1179921002',
    'message' => 'Body Hintergrund Farbe'
  },
  'body background color description' => {
    'lastUpdated' => '1179921012',
    'message' => 'Die Hintergrundfarbe des Bodies.'
  },
  'body content' => {
    'lastUpdated' => '1179921028',
    'message' => 'Body Inhalt hier.'
  },
  'body text color' => {
    'lastUpdated' => '1179921036',
    'message' => 'Body Textfarbe'
  },
  'body text color description' => {
    'lastUpdated' => '1179921052',
    'message' => 'Die Farbe des Textes im Body.'
  },
  'choose a layout' => {
    'lastUpdated' => '1179921086',
    'message' => 'Wählen Sie ein Layout für diesen Style:'
  },
  'css label' => {
    'lastUpdated' => '1243496792',
    'message' => 'Stilvorlage (CSS)'
  },
  'default parser' => {
    'lastUpdated' => '1179921095',
    'message' => 'Standard Parser'
  },
  'edit template' => {
    'lastUpdated' => '1179921120',
    'message' => 'Template bearbeiten'
  },
  'field storageIdExample' => {
    'lastUpdated' => '1273049011',
    'message' => 'Beispielbild'
  },
  'field storageIdExample description' => {
    'lastUpdated' => '1273049086',
    'message' => 'Ein Beispielbild das dem Nutzer vor der Auswahl das Aussehen eines Templates anzeigt.'
  },
  'head block' => {
    'lastUpdated' => '1179921129',
    'message' => 'Head Block'
  },
  'head block description' => {
    'lastUpdated' => '1179921269',
    'message' => 'Fügen Sie hier Meta Tags, Skript Tags, Link Tabellen, Style Sheets und alles das ein, was im Head Block (<head> ... </head>) ihres HTML Dokuments stehen soll.'
  },
  'header background color' => {
    'lastUpdated' => '1179921282',
    'message' => 'Hintergrundfarbe Header'
  },
  'header background color description' => {
    'lastUpdated' => '1179921369',
    'message' => 'Die Hintergrundfarbe ihres Headers oder des Banner Bereichs der Seite.'
  },
  'header text color' => {
    'lastUpdated' => '1179921377',
    'message' => 'Textfarbe Header'
  },
  'header text color description' => {
    'lastUpdated' => '1179921388',
    'message' => 'Die Farbe des Textes im Header.'
  },
  'heading' => {
    'lastUpdated' => '1179921396',
    'message' => 'Heading'
  },
  'js body label' => {
    'lastUpdated' => '1243496809',
    'message' => 'Javascript (body)'
  },
  'js head label' => {
    'lastUpdated' => '1243496823',
    'message' => 'Javascript (head)'
  },
  'link color' => {
    'lastUpdated' => '1179921410',
    'message' => 'Linkfarbe'
  },
  'link color description' => {
    'lastUpdated' => '1179921483',
    'message' => 'Farbe der Links auf ihrer Seite. Standard ist blau.'
  },
  'logo' => {
    'lastUpdated' => '1179921487',
    'message' => 'Logo'
  },
  'logo description' => {
    'lastUpdated' => '1179921549',
    'message' => 'Sie können dieses Feld benutzen, um ein graphisches Logo in ihr Style einzbinden. Das Logo darf h&ouml;chstens 200 Pixel breit und 100 Pixel hoch sein.'
  },
  'logo subtext' => {
    'lastUpdated' => '1179921574',
    'message' => 'Das Logo darf höchstens 200 Pixel breit und 100 Pixel hoch sein.'
  },
  'make duplicate label' => {
    'lastUpdated' => '1224797765',
    'message' => 'Diese Vorlage duplizieren und bearbeiten'
  },
  'menu' => {
    'lastUpdated' => '1179921582',
    'message' => 'Menü'
  },
  'menu background color' => {
    'lastUpdated' => '1179921596',
    'message' => 'Hintergrundfarbe des Menüs'
  },
  'menu background color description' => {
    'lastUpdated' => '1179921615',
    'message' => 'Die Hintergrundfarbe des Menübereichs ihrer Seite.'
  },
  'namespace' => {
    'lastUpdated' => '1179921622',
    'message' => 'Namensbereich'
  },
  'namespace description' => {
    'lastUpdated' => '1179921634',
    'message' => 'Welchen Typ hat dieses Template?'
  },
  'page background color' => {
    'lastUpdated' => '1179921644',
    'message' => 'Hintergrundfarbe der Seite'
  },
  'page background color description' => {
    'lastUpdated' => '1179921655',
    'message' => 'Die Hintergrundfarbe der ganzen Seite.'
  },
  'parser' => {
    'lastUpdated' => '1240167148',
    'message' => 'Template-Typ'
  },
  'parser description' => {
    'lastUpdated' => '1179921993',
    'message' => 'Falls ihre Konfigdatei mehrer Template Engines auflistet, dann wählen Sie den Typ des Templates, damit WebGUI das Template der richtigen Engine übergeben kann.'
  },
  'plugin enabled header' => {
    'lastUpdated' => '1179922001',
    'message' => 'Aktiviert?'
  },
  'plugin name' => {
    'lastUpdated' => '1179922010',
    'message' => 'Name des Parsers'
  },
  'session form variables' => {
    'lastUpdated' => '1179922203',
    'message' => '<strong>Session Formular Variablen</strong><br />Jede Formular Variable ist im Template in folgender Form verfügbar:<br /> &lt;tmpl_var session.form.<em>variable</em>&gt;<br /> Gibt es mehr als einen Wert f&uuml;r eine Formular Variable, so wird nur der letzte zur&uuml;ckgegeben.'
  },
  'session scratch variables' => {
    'lastUpdated' => '1179922262',
    'message' => '<strong>Session Scratch Variablen</strong><br />Jede scratch Variable ist in folgender Form im Template verfügbar:<br /> &lt;tmpl_var session.scratch.<em>variable</em>&gt;'
  },
  'session.config.extrasurl' => {
    'lastUpdated' => '1179922369',
    'message' => 'Die URL des extras Verzeichnisses auf dem Server; konfiguriert in der WebGUI.conf Datei.'
  },
  'session.setting.anonymousRegistration' => {
    'lastUpdated' => '1179922427',
    'message' => 'Gibt an, ob eine anonyme Registrierung eralaubt ist oder nicht; konfiguriert in den WebGUI Einstellungen.'
  },
  'session.setting.companyName' => {
    'lastUpdated' => '1179922436',
    'message' => 'Firmenname; konfiguriert in den WebGUI Einstellungen.'
  },
  'session.user.firstDayOfWeek' => {
    'lastUpdated' => '1179922474',
    'message' => 'Der konfigurierte erste Tag der Woche; konfiguriert im Profil des aktuellen Benutzers.'
  },
  'session.user.username' => {
    'lastUpdated' => '1179922488',
    'message' => 'Der Benutzername des aktuelle Benutzers.'
  },
  'session.var.adminOn' => {
    'lastUpdated' => '1179922514',
    'message' => 'Bedingung, die wahr ist, falls sich der aktuelle Benutzer im Admin Modus befindet.'
  },
  'show in forms' => {
    'lastUpdated' => '1179922524',
    'message' => 'In Formularen anzeigen?'
  },
  'show in forms description' => {
    'lastUpdated' => '1179922600',
    'message' => 'Soll dieses Template in der Liste der Templates dieses Namensbereichs angezeigt werden?'
  },
  'site name' => {
    'lastUpdated' => '1179922614',
    'message' => 'Name der Site'
  },
  'site name description' => {
    'lastUpdated' => '1179922626',
    'message' => 'Der Name ihrer Website'
  },
  'style wizard' => {
    'lastUpdated' => '1179922645',
    'message' => 'Style Wizard'
  },
  'template description' => {
    'lastUpdated' => '1179922687',
    'message' => 'Erzeugen Sie ihr Template, in dem sie Template Kommandos und Variablen, Makros und HTML benutzen.'
  },
  'template error' => {
    'lastUpdated' => '1254901998',
    'message' => 'Sie haben einen Syntaxfehler in diesem Template, %s, %s, %s. Bitte korrigieren Sie diesen.'
  },
  'template in clipboard' => {
    'lastUpdated' => '1254902008',
    'message' => 'Template in Zwischenablage'
  },
  'template in trash' => {
    'lastUpdated' => '1254902021',
    'message' => 'Template im Papierkorb'
  },
  'template parsers' => {
    'lastUpdated' => '1179922723',
    'message' => 'Template Parser'
  },
  'template parsers list body' => {
    'lastUpdated' => '1179922751',
    'message' => 'Die folgenden Template Parser sind auf ihrer Site installiert und können aktiviert werden.'
  },
  'template parsers list title' => {
    'lastUpdated' => '1179922770',
    'message' => 'Liste von Template Parsern'
  },
  'template variable title' => {
    'lastUpdated' => '1179922782',
    'message' => 'Template Variablen'
  },
  'usePacked description' => {
    'lastUpdated' => '1241189978',
    'message' => 'Komprimierte Version dieser Vorlage verwenden. (für schnellere Downloads)'
  },
  'usePacked label' => {
    'lastUpdated' => '1241190004',
    'message' => 'Vorlage komprimieren?'
  },
  'visited link color' => {
    'lastUpdated' => '1179922792',
    'message' => 'Farbe der besuchten Links'
  },
  'visited link color description' => {
    'lastUpdated' => '1179922813',
    'message' => 'Die Farbe der besuchten Links auf ihrer Site. Standard ist lila.'
  },
  'warning default template' => {
    'lastUpdated' => '1224797895',
    'message' => 'Sie versuchen eine Standardvorlage zu bearbeiten. Jede Änderung könnte verloren gehen, wenn Sie WebGUI aktualisieren. Besser wäre es, diese Vorlage zu duplizieren.'
  },
  'webgui.status' => {
    'lastUpdated' => '1179922845',
    'message' => 'Der Release Status dieser WebGUI Version (stabel, beta, gamma, etc.)'
  },
  'webgui.version' => {
    'lastUpdated' => '1243496964',
    'message' => 'Version Ihrer WebGUI Installation'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Template.pm <==
package WebGUI::i18n::German::Asset_Template;
use utf8;
our $I18N = {
  'Already attached!' => {
    'lastUpdated' => '1258547405',
    'message' => 'Bereits angehängt!'
  },
  'Configure' => {
    'lastUpdated' => '1295597015',
    'message' => 'Konfigurieren'
  },
  'Configure Preview' => {
    'lastUpdated' => '1295597025',
    'message' => 'Vorschau konfigurieren'
  },
  'Fetch' => {
    'lastUpdated' => '1295597032',
    'message' => 'Holen'
  },
  'Fetch Variables' => {
    'lastUpdated' => '1295597044',
    'message' => 'Variable holen'
  },
  'Fetch Variables hoverHelp' => {
    'lastUpdated' => '1295597085',
    'message' => 'Versucht die Variablen aus der URL zu bestimmen, die dieses Template benutzt.'
  },
  'No url!' => {
    'lastUpdated' => '1258547392',
    'message' => 'Keine URL!'
  },
  'Plain Text hoverHelp' => {
    'lastUpdated' => '1295597201',
    'message' => 'Wenn mit JA markiert, wird die Ausgabe als Plain-Text formatiert (nützlich um die Original-Ausgabe eines Templates zu prüfen). Andernfalls wird die Ausgabe in HTML gerendert.'
  },
  'Plain Text?' => {
    'lastUpdated' => '1295597233',
    'message' => 'Vorschau als Plain-Text?'
  },
  'Preview' => {
    'lastUpdated' => '1295597239',
    'message' => 'Vorschau'
  },
  'URL' => {
    'lastUpdated' => '1295597246',
    'message' => 'URL'
  },
  'URL hoverHelp' => {
    'lastUpdated' => '1295597264',
    'message' => 'URL des Hole-Buttons'
  },
  'Variables' => {
    'lastUpdated' => '1295597273',
    'message' => 'Variablen'
  },
  'Variables hoverHelp' => {
    'lastUpdated' => '1295597300',
    'message' => 'Variablen die vom Render-Button verwandt werden (in JSON).'
  },
  'assetName' => {
    'lastUpdated' => '1179920785',
    'message' => 'Template'
  },
  'attachment add button' => {
    'lastUpdated' => '1243496763',
    'message' => 'Hinzufügen'
  },
  'attachment add field label' => {
    'lastUpdated' => '1243496838',
    'message' => 'Anhang hinzufügen'
  },
  'attachment display label' => {
    'lastUpdated' => '1243496774',
    'message' => 'Anhänge'
  },
  'attachment header index' => {
    'lastUpdated' => '1243496871',
    'message' => 'Anhang-Nr.'
  },
  'attachment header remove' => {
    'lastUpdated' => '1243496881',
    'message' => 'Entfernen'
  },
  'attachment header type' => {
    'lastUpdated' => '1243496897',
    'message' => 'Typ'
  },
  'attachment header url' => {
    'lastUpdated' => '1295597333',
    'message' => 'URL'
  },
  'body background color' => {
    'lastUpdated' => '1179921002',
    'message' => 'Body Hintergrund Farbe'
  },
  'body background color description' => {
    'lastUpdated' => '1179921012',
    'message' => 'Die Hintergrundfarbe des Bodies.'
  },
  'body content' => {
    'lastUpdated' => '1179921028',
    'message' => 'Body Inhalt hier.'
  },
  'body text color' => {
    'lastUpdated' => '1179921036',
    'message' => 'Body Textfarbe'
  },
  'body text color description' => {
    'lastUpdated' => '1179921052',
    'message' => 'Die Farbe des Textes im Body.'
  },
  'choose a layout' => {
    'lastUpdated' => '1179921086',
    'message' => 'Wählen Sie ein Layout für diesen Style:'
  },
  'css label' => {
    'lastUpdated' => '1243496792',
    'message' => 'Stilvorlage (CSS)'
  },
  'default parser' => {
    'lastUpdated' => '1179921095',
    'message' => 'Standard Parser'
  },
  'edit template' => {
    'lastUpdated' => '1179921120',
    'message' => 'Template bearbeiten'
  },
  'field storageIdExample' => {
    'lastUpdated' => '1273049011',
    'message' => 'Beispielbild'
  },
  'field storageIdExample description' => {
    'lastUpdated' => '1273049086',
    'message' => 'Ein Beispielbild das dem Nutzer vor der Auswahl das Aussehen eines Templates anzeigt.'
  },
  'head block' => {
    'lastUpdated' => '1179921129',
    'message' => 'Head Block'
  },
  'head block description' => {
    'lastUpdated' => '1179921269',
    'message' => 'Fügen Sie hier Meta Tags, Skript Tags, Link Tabellen, Style Sheets und alles das ein, was im Head Block (<head> ... </head>) ihres HTML Dokuments stehen soll.'
  },
  'header background color' => {
    'lastUpdated' => '1179921282',
    'message' => 'Hintergrundfarbe Header'
  },
  'header background color description' => {
    'lastUpdated' => '1179921369',
    'message' => 'Die Hintergrundfarbe ihres Headers oder des Banner Bereichs der Seite.'
  },
  'header text color' => {
    'lastUpdated' => '1179921377',
    'message' => 'Textfarbe Header'
  },
  'header text color description' => {
    'lastUpdated' => '1179921388',
    'message' => 'Die Farbe des Textes im Header.'
  },
  'heading' => {
    'lastUpdated' => '1179921396',
    'message' => 'Heading'
  },
  'js body label' => {
    'lastUpdated' => '1243496809',
    'message' => 'Javascript (body)'
  },
  'js head label' => {
    'lastUpdated' => '1243496823',
    'message' => 'Javascript (head)'
  },
  'link color' => {
    'lastUpdated' => '1179921410',
    'message' => 'Linkfarbe'
  },
  'link color description' => {
    'lastUpdated' => '1179921483',
    'message' => 'Farbe der Links auf ihrer Seite. Standard ist blau.'
  },
  'logo' => {
    'lastUpdated' => '1179921487',
    'message' => 'Logo'
  },
  'logo description' => {
    'lastUpdated' => '1179921549',
    'message' => 'Sie können dieses Feld benutzen, um ein graphisches Logo in ihr Style einzbinden. Das Logo darf h&ouml;chstens 200 Pixel breit und 100 Pixel hoch sein.'
  },
  'logo subtext' => {
    'lastUpdated' => '1179921574',
    'message' => 'Das Logo darf höchstens 200 Pixel breit und 100 Pixel hoch sein.'
  },
  'make duplicate label' => {
    'lastUpdated' => '1224797765',
    'message' => 'Diese Vorlage duplizieren und bearbeiten'
  },
  'menu' => {
    'lastUpdated' => '1179921582',
    'message' => 'Menü'
  },
  'menu background color' => {
    'lastUpdated' => '1179921596',
    'message' => 'Hintergrundfarbe des Menüs'
  },
  'menu background color description' => {
    'lastUpdated' => '1179921615',
    'message' => 'Die Hintergrundfarbe des Menübereichs ihrer Seite.'
  },
  'namespace' => {
    'lastUpdated' => '1179921622',
    'message' => 'Namensbereich'
  },
  'namespace description' => {
    'lastUpdated' => '1179921634',
    'message' => 'Welchen Typ hat dieses Template?'
  },
  'page background color' => {
    'lastUpdated' => '1179921644',
    'message' => 'Hintergrundfarbe der Seite'
  },
  'page background color description' => {
    'lastUpdated' => '1179921655',
    'message' => 'Die Hintergrundfarbe der ganzen Seite.'
  },
  'parser' => {
    'lastUpdated' => '1240167148',
    'message' => 'Template-Typ'
  },
  'parser description' => {
    'lastUpdated' => '1179921993',
    'message' => 'Falls ihre Konfigdatei mehrer Template Engines auflistet, dann wählen Sie den Typ des Templates, damit WebGUI das Template der richtigen Engine übergeben kann.'
  },
  'plugin enabled header' => {
    'lastUpdated' => '1179922001',
    'message' => 'Aktiviert?'
  },
  'plugin name' => {
    'lastUpdated' => '1179922010',
    'message' => 'Name des Parsers'
  },
  'session form variables' => {
    'lastUpdated' => '1179922203',
    'message' => '<strong>Session Formular Variablen</strong><br />Jede Formular Variable ist im Template in folgender Form verfügbar:<br /> &lt;tmpl_var session.form.<em>variable</em>&gt;<br /> Gibt es mehr als einen Wert f&uuml;r eine Formular Variable, so wird nur der letzte zur&uuml;ckgegeben.'
  },
  'session scratch variables' => {
    'lastUpdated' => '1179922262',
    'message' => '<strong>Session Scratch Variablen</strong><br />Jede scratch Variable ist in folgender Form im Template verfügbar:<br /> &lt;tmpl_var session.scratch.<em>variable</em>&gt;'
  },
  'session.config.extrasurl' => {
    'lastUpdated' => '1179922369',
    'message' => 'Die URL des extras Verzeichnisses auf dem Server; konfiguriert in der WebGUI.conf Datei.'
  },
  'session.setting.anonymousRegistration' => {
    'lastUpdated' => '1179922427',
    'message' => 'Gibt an, ob eine anonyme Registrierung eralaubt ist oder nicht; konfiguriert in den WebGUI Einstellungen.'
  },
  'session.setting.companyName' => {
    'lastUpdated' => '1179922436',
    'message' => 'Firmenname; konfiguriert in den WebGUI Einstellungen.'
  },
  'session.user.firstDayOfWeek' => {
    'lastUpdated' => '1179922474',
    'message' => 'Der konfigurierte erste Tag der Woche; konfiguriert im Profil des aktuellen Benutzers.'
  },
  'session.user.username' => {
    'lastUpdated' => '1179922488',
    'message' => 'Der Benutzername des aktuelle Benutzers.'
  },
  'session.var.adminOn' => {
    'lastUpdated' => '1179922514',
    'message' => 'Bedingung, die wahr ist, falls sich der aktuelle Benutzer im Admin Modus befindet.'
  },
  'show in forms' => {
    'lastUpdated' => '1179922524',
    'message' => 'In Formularen anzeigen?'
  },
  'show in forms description' => {
    'lastUpdated' => '1179922600',
    'message' => 'Soll dieses Template in der Liste der Templates dieses Namensbereichs angezeigt werden?'
  },
  'site name' => {
    'lastUpdated' => '1179922614',
    'message' => 'Name der Site'
  },
  'site name description' => {
    'lastUpdated' => '1179922626',
    'message' => 'Der Name ihrer Website'
  },
  'style wizard' => {
    'lastUpdated' => '1179922645',
    'message' => 'Style Wizard'
  },
  'template description' => {
    'lastUpdated' => '1179922687',
    'message' => 'Erzeugen Sie ihr Template, in dem sie Template Kommandos und Variablen, Makros und HTML benutzen.'
  },
  'template error' => {
    'lastUpdated' => '1254901998',
    'message' => 'Sie haben einen Syntaxfehler in diesem Template, %s, %s, %s. Bitte korrigieren Sie diesen.'
  },
  'template in clipboard' => {
    'lastUpdated' => '1254902008',
    'message' => 'Template in Zwischenablage'
  },
  'template in trash' => {
    'lastUpdated' => '1254902021',
    'message' => 'Template im Papierkorb'
  },
  'template parsers' => {
    'lastUpdated' => '1179922723',
    'message' => 'Template Parser'
  },
  'template parsers list body' => {
    'lastUpdated' => '1179922751',
    'message' => 'Die folgenden Template Parser sind auf ihrer Site installiert und können aktiviert werden.'
  },
  'template parsers list title' => {
    'lastUpdated' => '1179922770',
    'message' => 'Liste von Template Parsern'
  },
  'template variable title' => {
    'lastUpdated' => '1179922782',
    'message' => 'Template Variablen'
  },
  'usePacked description' => {
    'lastUpdated' => '1241189978',
    'message' => 'Komprimierte Version dieser Vorlage verwenden. (für schnellere Downloads)'
  },
  'usePacked label' => {
    'lastUpdated' => '1241190004',
    'message' => 'Vorlage komprimieren?'
  },
  'visited link color' => {
    'lastUpdated' => '1179922792',
    'message' => 'Farbe der besuchten Links'
  },
  'visited link color description' => {
    'lastUpdated' => '1179922813',
    'message' => 'Die Farbe der besuchten Links auf ihrer Site. Standard ist lila.'
  },
  'warning default template' => {
    'lastUpdated' => '1224797895',
    'message' => 'Sie versuchen eine Standardvorlage zu bearbeiten. Jede Änderung könnte verloren gehen, wenn Sie WebGUI aktualisieren. Besser wäre es, diese Vorlage zu duplizieren.'
  },
  'webgui.status' => {
    'lastUpdated' => '1179922845',
    'message' => 'Der Release Status dieser WebGUI Version (stabel, beta, gamma, etc.)'
  },
  'webgui.version' => {
    'lastUpdated' => '1243496964',
    'message' => 'Version Ihrer WebGUI Installation'
  }
}
;

1;
